==> linshare-0.2.0.tgz: linshare/linshare.php <==
<?php 

/******************************************************************************
Copyright (C) 2014 Linagora

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU Affero General Public License as published by the Free
Software Foundation, either version 3 of the License, or (at your option) any
later version, provided you comply with the Additional Terms applicable for OBM
software by Linagora pursuant to Section 7 of the GNU Affero General Public
License, subsections (b), (c), and (e), pursuant to which you must notably (i)
retain the displaying by the interactive user interfaces of the “OBM, Free
Communication by Linagora” Logo with the “You are using the Open Source and
free version of OBM developed and supported by Linagora. Contribute to OBM R&D
by subscribing to an Enterprise offer !” infobox, (ii) retain all hypertext
links between OBM and obm.org, between Linagora and linagora.com, as well as
between the expression “Enterprise offer” and pro.obm.org, and (iii) refrain
from infringing Linagora intellectual property rights over its trademarks and
commercial brands. Other Additional Terms apply, see
<http://www.linagora.com/licenses/> for more details.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License and
its applicable Additional Terms for OBM along with this program. If not, see
<http://www.gnu.org/licenses/> for the GNU Affero General   Public License
version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
applicable to the OBM software.
******************************************************************************/

class linshare extends rcube_plugin
{
	public $task = 'mail|settings';

	function init()
	{
		$rcmail = rcmail::get_instance();
		$prefs = rcmail::get_instance()->user->get_prefs();

		$this->add_hook('attachment_upload', array($this, 'queueFile'));
		$this->register_action('plugin.triggerUpload', array($this, 'upload_Linshare'));    
		$this->add_hook('message_outgoing_headers', array($this, 'get_emailAddresses'));
		$this->register_action('plugin.delete_attachments', array($this, 'delete_attachments'));
		$this->add_hook('message_before_send', array($this, 'share_linshare'));
		$this->add_hook('message_compose', array($this, 'cleanup'));   

		if ($rcmail->task == 'mail'){       

			if ($rcmail->action == 'compose') {
				$skin_path = $this->local_skin_path();        
				$this->include_script('linshare.js');

				if (is_file($this->home . "/$skin_path/linshare.css")){
					$this->include_stylesheet("$skin_path/linshare.css");
				}

				$this->add_texts('localization', true);
				$linshare_button = array(          
					'command' => 'plugin.linshare',
					'label' => 'buttonText',
					'title' => 'buttonTitle',
					'class' => 'button linshareButton',   
					'domain' => $this->ID);
				$this->add_button($linshare_button, 'toolbar');
			} 
		}
		else if ($rcmail->task == 'settings') { 

			$skin_path = $this->local_skin_path();
			if (is_file($this->home . "/$skin_path/linshare.css"))
				$this->include_stylesheet("$skin_path/linshare.css");

			$this->add_hook('preferences_sections_list', array($this, 'linshare_sections_list')); 
			$this->add_hook('preferences_list', array($this, 'linshare_list')); 
			$this->add_hook('preferences_save', array($this, 'linshare_save'));  
		}
	}  

	function upload_Linshare(){		

		$rcmail = rcmail::get_instance();    
		$prefs = $rcmail->user->get_prefs();
		$username = $prefs['loginLinshare'];
		$password = $prefs['pwdLinshare'];				 
		$_SESSION['plugins']['linshare']['rc_Attachments']=array();   
		$_SESSION['plugins']['linshare']['uuids']=array();   
		$_SESSION['plugins']['linshare']['emailAddresses'] = array(); 		
		$url = $this->get_base();		
		$uploadFileUrl = $url."/document/upload";

    // Filter the table
		if($_SESSION['plugins']['filesystem_attachments']!=NULL){
			foreach ($_SESSION['plugins']['filesystem_attachments'] as $group => $files) {
				$_SESSION['plugins']['linshare']['rc_Attachments'][$group] = array_filter($files , 'file_exists');         
			}
			$_SESSION['plugins']['linshare']['rc_Attachments'] = array_filter($_SESSION['plugins']['linshare']['rc_Attachments']);
		}


		if($_SESSION['plugins']['linshare']['rc_Attachments']!=NULL){
			if ($ch = curl_init()) {
				foreach ($_SESSION['plugins']['linshare']['rc_Attachments'] as $group => $files) {
					foreach ($files as $filePath) {   
						$file=file_get_contents($filePath); 

						$filename=$this->originalName($filePath);            
						$headers = array("Content-Type:multipart/form-data; charset=iso-8859-1",
							"Accept: application/json",
							"Authorization: Basic " . base64_encode(
								$username.':'.$password) );                  
						$postfields = array(
							"file"=>$file,            
							"filename"=>$filename
							); 
						$options = array(              
							CURLOPT_RETURNTRANSFER => true,
							CURLOPT_URL => $uploadFileUrl,
							CURLOPT_POST => 1,
							CURLOPT_HEADER => 0,              
							CURLOPT_HTTPHEADER => $headers,
							CURLOPT_POSTFIELDS => $postfields,
							CURLOPT_SSL_VERIFYPEER=> false              
							);  

						curl_setopt_array($ch, $options);
						$response=curl_exec($ch);             
						$uuid=json_decode($response)->{'uuid'};           
						$_SESSION['plugins']['linshare']['uuids'][]=$uuid;
						$info = curl_getinfo($ch); 

						if(curl_errno($ch) || $info['http_code'] != 200 ){
							$rcmail->output->command('plugin.errorUpload', array());    
							return;                 
						}          

					}   
				} 
				curl_close($ch);
			}
			else{                      
				$rcmail->output->command('plugin.errorUpload', array());
				return;                          
			}

			if($prefs['textLinshare'] != ''){
				$rcmail->output->command('plugin.textLinshare', array('textLinshare' => $prefs['textLinshare']));
			}
			else{
				$this->load_config();
				$message = $rcmail->config->get('message');  
				$rcmail->output->command('plugin.textLinshare', array('textLinshare' => $message));      
			}      
		}    

		$_SESSION['plugins']['linshare']['filePaths']=array();    
		rcmail::get_instance()->output->command('plugin.uploaded', array('message'=>'done.')); 
	}

	function delete_attachments(){ 

		$rcmail = rcmail::get_instance();
		$compose_id = $this->retrieve_compose_id(); 

		if($compose_id != ''){
			$session_key = 'compose_data_' . $compose_id;
			$compose = $_SESSION[ $session_key ]; 

			foreach($compose['attachments'] as $id => $attachment){   
				$attachment = $rcmail->plugins->exec_hook('attachment_delete', $attachment);                  
				$rcmail->session->remove($session_key.'.attachments.'.$id);
				$rcmail->output->command('remove_from_attachment_list', "rcmfile$id");
			}     

		}
	}	

	function retrieve_compose_id(){
		$rcmail = rcmail::get_instance();
		$compose_data_keys = array_keys($_SESSION);
		$compose_data_keys = array_filter($compose_data_keys , array($this, 'isComposeDataKey'));
		$file_ids = array_keys(reset($_SESSION['plugins']['linshare']['rc_Attachments']));
		$file_id_to_find = $file_ids[0];

		foreach ($compose_data_keys as $compose_id){
			$msg_attachments = $_SESSION[$compose_id]['attachments'];     

			if($msg_attachments != null){
				foreach($msg_attachments as $key => $attachment){
					if($attachment['id'] == $file_id_to_find){
						return $_SESSION[$compose_id]['id'];
					}
				}
			}

		}  
	}

	function share_linshare($args){ 

		if($_SESSION['plugins']['linshare']['uuids']!=NULL){

			$prefs = rcmail::get_instance()->user->get_prefs();			
			$username = $prefs['loginLinshare'];
			$password = $prefs['pwdLinshare'];			     
			$mail_array = $_SESSION['plugins']['linshare']['emailAddresses'];         
			$url = $this->get_base();				
			$share_url = $url."/share/multiplesharedocuments";  

			foreach ($mail_array as $mail) { 

				$postfields = "";       

      //Share uploaded files with each recipient

				foreach ($_SESSION['plugins']['linshare']['uuids'] as $uuid){
					$postfields = $postfields."&file=".$uuid;        
				}

				$postfields = "targetMail=".$mail.$postfields; 

				$headers = array("Authorization: Basic " . base64_encode(
					$username.':'.$password));
				$options = array(
					CURLOPT_RETURNTRANSFER => true,
					CURLOPT_URL => $share_url,
					CURLOPT_POST => 1,
					CURLOPT_HEADER => 0,             
					CURLOPT_HTTPHEADER =>$headers,
					CURLOPT_POSTFIELDS => $postfields,
					CURLOPT_SSL_VERIFYPEER=> false
					);             

				if ($ch = curl_init()) {
					curl_setopt_array($ch, $options);          
					$response=curl_exec($ch);        

					if(!curl_errno($ch)){
						$info = curl_getinfo($ch);
					}

					curl_close($ch); 
				}       
			}    

		}

		$_SESSION['plugins']['linshare']['uuids']=array();
		$_SESSION['plugins']['linshare']['fileIds']=array();
	}  

	function get_base(){		   
		$rcmail = rcmail::get_instance();
		$prefs = $rcmail->user->get_prefs();

		if($prefs['urlLinshare'] != '')
			$url = $prefs['urlLinshare'];		
		else{
			$this->load_config();
			$url = $rcmail->config->get('url');
		}

		return $url;
	}

	function queueFile($args){ 
    //Saving file's name
		$_SESSION['plugins']['linshare']['filePaths'][$args['name']] = $args['path']; 
		$_SESSION['plugins']['linshare']['fileIds'][$args['name']] = $args['id']; 
		return $args;
	}

	function originalName($filePath){

		foreach($_SESSION['plugins']['linshare']['filePaths'] as $name =>$path){
			if($path==$filePath){        
				return $name;     
			}
		}
	} 

	function cleanup($args){
		rcmail::get_instance()->plugins->exec_hook('attachments_cleanup', array()); 
		return $args;
	}

	function linshare_sections_list($p)
	{
		$this->add_texts('localization/');    

		$p['list']['linshare'] = array(
			'id' => 'linshare', 'section' => $this->gettext('linshareSettings')
			);

		return $p;
	}

	function linshare_list($p){
		$rcmail = rcmail::get_instance();    
		$prefs = rcmail::get_instance()->user->get_prefs();
		$urlLinshareValue = $prefs['urlLinshare'];
		$loginLinshareValue = $prefs['loginLinshare'];
		$pwdLinshareValue = $prefs['pwdLinshare'];
		$textLinshareValue = $prefs['textLinshare']; 
		$this->add_texts('localization');  

		if ($p['section'] == 'linshare') {

			if($urlLinshareValue != ''){
				$urlLinshare=array(
					'title'=>$this->gettext('urlLinshareLabel'), 
					'content'=>"<input name='urlLinshareName' 
					type='url' 
					style='width:30em; height:1.5em' 
					value='$urlLinshareValue'>"
					);
			}
			if($urlLinshareValue == ''){
				$this->load_config();
				$urlDefault = $rcmail->config->get('url');  
				$urlLinshare=array(
					'title'=>$this->gettext('urlLinshareLabel'), 
					'content'=>"<input name='urlLinshareName' 
					type='url' 
					style='width:30em; height:1.5em' 
					placeholder='$urlDefault'>"
					);
			}
			$loginLinshare=array(
				'title'=>$this->gettext('loginLinshareLabel'), 
				'content'=>"<input name='loginLinshareName' 
				type='email' 
				style='width:30em; height:1.5em' 
				value='$loginLinshareValue'>"
				);
			$pwdLinshare=array(
				'title'=>$this->gettext('pwdLinshareLabel'), 
				'content'=>"<input type='password' 
				name='pwdLinshareName' 
				value='$pwdLinshareValue' 
				style='width:30em; height:1.5em' >"
				);

			if($textLinshareValue == ''){        
				$this->load_config();
				$message = $rcmail->config->get('message');  
				$textLinshare=array(
					'title'=>$this->gettext('textLinshareLabel'), 
					'content'=>"<textarea id='textLinshareID' placeholder='$message' name='textLinshareName' style='width:30em; height:8em'></textarea>");
			}

			if($textLinshareValue != ''){
				$textLinshare=array(
					'title'=>$this->gettext('textLinshareLabel'), 
					'content'=>"<textarea id='textLinshareID' name='textLinshareName' style='width:30em; height:8em'>$textLinshareValue</textarea>");
			}

			$options= array(
				'urlLinshare' => $urlLinshare, 
				'loginLinshare' => $loginLinshare, 
				'pwdLinshare' => $pwdLinshare,
				'textLinshare' => $textLinshare
				);
			$p['blocks']['main'] = array(
				'name' => $this->gettext('linshareAuthentication'),  
				'options' => $options
				);
		}
		return $p;      
	}

	function linshare_save($p){   
		$this->add_texts('localization');
		$rcmail = rcmail::get_instance();        

		if ($p['section'] == 'linshare') {
			$p['prefs']['urlLinshare'] = rcube_utils::get_input_value('urlLinshareName', rcube_utils::INPUT_POST);
			$p['prefs']['loginLinshare'] = rcube_utils::get_input_value('loginLinshareName', rcube_utils::INPUT_POST);
			$p['prefs']['pwdLinshare'] = rcube_utils::get_input_value('pwdLinshareName', rcube_utils::INPUT_POST);
			$p['prefs']['textLinshare'] = rcube_utils::get_input_value('textLinshareName', rcube_utils::INPUT_POST);
		}

		return $p; 
	}

	function get_emailAddresses($p){
		$to = $this->splitMail($p['headers']['To']);
		$cc = $this->splitMail($p['headers']['Cc']);
		$bcc = $this->splitMail($p['headers']['Bcc']);

		$a = array_merge($to, $cc, $bcc);
		$_SESSION['plugins']['linshare']['emailAddresses'] = array_filter($a);
	}

	function splitMail($stringMail){
		$finalArrayMail = array();
		$initialArrayMail = explode(',', $stringMail);    

		$finalArrayMail = array_map( array($this,'extract_mail'), $initialArrayMail); 
		return $finalArrayMail;   
	}  

	function extract_mail($str){
		$regex = '#.*\<(.*)\>.*$#';
		$str = trim($str);      
		$str = preg_replace($regex, '$1' ,$str);
		return $str;
	}

	function isComposeDataKey($p){
		return strpos($p,'compose_data_') === 0;
	}
}

==> linshare-0.3.0.tgz: linshare/linshare.php <==
<?php 

/******************************************************************************
Copyright (C) 2014 Linagora

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU Affero General Public License as published by the Free
Software Foundation, either version 3 of the License, or (at your option) any
later version, provided you comply with the Additional Terms applicable for OBM
software by Linagora pursuant to Section 7 of the GNU Affero General Public
License, subsections (b), (c), and (e), pursuant to which you must notably (i)
retain the displaying by the interactive user interfaces of the “OBM, Free
Communication by Linagora” Logo with the “You are using the Open Source and
free version of OBM developed and supported by Linagora. Contribute to OBM R&D
by subscribing to an Enterprise offer !” infobox, (ii) retain all hypertext
links between OBM and obm.org, between Linagora and linagora.com, as well as
between the expression “Enterprise offer” and pro.obm.org, and (iii) refrain
from infringing Linagora intellectual property rights over its trademarks and
commercial brands. Other Additional Terms apply, see
<http://www.linagora.com/licenses/> for more details.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License and
its applicable Additional Terms for OBM along with this program. If not, see
<http://www.gnu.org/licenses/> for the GNU Affero General   Public License
version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
applicable to the OBM software.
******************************************************************************/

class linshare extends rcube_plugin
{

	const SIMPLE_AUTH_KIND = 'simple';
	const LEMONLDAP_AUTH_KIND = 'lemonldap';

	private static $VALID_AUTH_KINDS = array(
		linshare::SIMPLE_AUTH_KIND,
		linshare::LEMONLDAP_AUTH_KIND
	);

	public $task = 'mail|settings';

	function init()
	{
		$rcmail = rcmail::get_instance();

		$this->add_hook('attachment_upload', array($this, 'queueFile'));
		$this->register_action('plugin.triggerUpload', array($this, 'upload_Linshare'));    
		$this->add_hook('message_outgoing_headers', array($this, 'get_emailAddresses'));
		$this->register_action('plugin.delete_attachments', array($this, 'delete_attachments'));
		$this->add_hook('message_before_send', array($this, 'share_linshare'));
		$this->add_hook('message_compose', array($this, 'cleanup'));   

		if ($rcmail->task == 'mail'){       

			if ($rcmail->action == 'compose') {
				$skin_path = $this->local_skin_path();        
				$this->include_script('linshare.js');

				if (is_file($this->home . "/$skin_path/linshare.css")){
					$this->include_stylesheet("$skin_path/linshare.css");
				}

				$this->add_texts('localization', true);
				$linshare_button = array(          
					'command' => 'plugin.linshare',
					'label' => 'buttonText',
					'title' => 'buttonTitle',
					'class' => 'button linshareButton',   
					'domain' => $this->ID);
				$this->add_button($linshare_button, 'toolbar');
			} 
		}
		else if ($rcmail->task == 'settings') { 

			$skin_path = $this->local_skin_path();
			if (is_file($this->home . "/$skin_path/linshare.css"))
				$this->include_stylesheet("$skin_path/linshare.css");

			$this->add_hook('preferences_sections_list', array($this, 'linshare_sections_list')); 
			$this->add_hook('preferences_list', array($this, 'linshare_list')); 
			$this->add_hook('preferences_save', array($this, 'linshare_save'));  
		}
	}

	function getAuthKind() {
		$this->load_config();
		$authKind = rcmail::get_instance()->config->get('linshare_authKind', linshare::SIMPLE_AUTH_KIND);

		if ( !in_array($authKind, linshare::$VALID_AUTH_KINDS)) {
			$authKind = linshare::SIMPLE_AUTH_KIND;
		}

		return $authKind;
	}

	function getUserCredentials() {
		$authKind = $this->getAuthKind();

		switch ($authKind) {
			case linshare::SIMPLE_AUTH_KIND :
				$prefs = rcmail::get_instance()->user->get_prefs();

				return array(
					"username" => $prefs['loginLinshare'],
					"password" => $prefs['pwdLinshare']
				);
			case linshare::LEMONLDAP_AUTH_KIND :
				return array(
					"username" => $_SERVER["PHP_AUTH_USER"],
					"password" => $_SERVER["PHP_AUTH_PW"]
				);
		}
	}

	function upload_Linshare(){		
		$rcmail = rcmail::get_instance();
		$prefs = $rcmail->user->get_prefs();
		$_SESSION['plugins']['linshare']['rc_Attachments']=array();   
		$_SESSION['plugins']['linshare']['uuids']=array();   
		$_SESSION['plugins']['linshare']['emailAddresses'] = array(); 		
		$url = $this->get_base();		
		$uploadFileUrl = $url."/document/upload";

    // Filter the table
		if($_SESSION['plugins']['filesystem_attachments']!=NULL){
			foreach ($_SESSION['plugins']['filesystem_attachments'] as $group => $files) {
				$_SESSION['plugins']['linshare']['rc_Attachments'][$group] = array_filter($files , 'file_exists');         
			}
			$_SESSION['plugins']['linshare']['rc_Attachments'] = array_filter($_SESSION['plugins']['linshare']['rc_Attachments']);
		}


		if($_SESSION['plugins']['linshare']['rc_Attachments']!=NULL){
			$credentials = $this->getUserCredentials();

			if ($ch = curl_init()) {
				foreach ($_SESSION['plugins']['linshare']['rc_Attachments'] as $group => $files) {
					foreach ($files as $filePath) {   
						$file=file_get_contents($filePath); 

						$filename=$this->originalName($filePath);            
						$headers = array("Content-Type:multipart/form-data; charset=iso-8859-1",
							"Accept: application/json",
							"Authorization: Basic " . base64_encode($credentials["username"] . ':' . $credentials["password"]));                  
						$postfields = array(
							"file"=>$file,            
							"filename"=>$filename
							); 
						$options = array(              
							CURLOPT_RETURNTRANSFER => true,
							CURLOPT_URL => $uploadFileUrl,
							CURLOPT_POST => 1,
							CURLOPT_HEADER => 0,              
							CURLOPT_HTTPHEADER => $headers,
							CURLOPT_POSTFIELDS => $postfields,
							CURLOPT_SSL_VERIFYPEER=> false              
							);  

						curl_setopt_array($ch, $options);
						$response=curl_exec($ch);             
						$uuid=json_decode($response)->{'uuid'};           
						$_SESSION['plugins']['linshare']['uuids'][]=$uuid;
						$info = curl_getinfo($ch); 

						if(curl_errno($ch) || $info['http_code'] != 200 ){
							$rcmail->output->command('plugin.errorUpload', array());    
							return;                 
						}          

					}   
				} 
				curl_close($ch);
			}
			else{                      
				$rcmail->output->command('plugin.errorUpload', array());
				return;                          
			}

			if($prefs['textLinshare'] != ''){
				$rcmail->output->command('plugin.textLinshare', array('textLinshare' => $prefs['textLinshare']));
			}
			else{
				$this->load_config();
				$message = $rcmail->config->get('linshare_message');
				$rcmail->output->command('plugin.textLinshare', array('textLinshare' => $message));      
			}      
		}    

		$_SESSION['plugins']['linshare']['filePaths']=array();    
		rcmail::get_instance()->output->command('plugin.uploaded', array('message'=>'done.')); 
	}

	function delete_attachments(){ 

		$rcmail = rcmail::get_instance();
		$compose_id = $this->retrieve_compose_id(); 

		if($compose_id != ''){
			$session_key = 'compose_data_' . $compose_id;
			$compose = $_SESSION[ $session_key ]; 

			foreach($compose['attachments'] as $id => $attachment){   
				$attachment = $rcmail->plugins->exec_hook('attachment_delete', $attachment);                  
				$rcmail->session->remove($session_key.'.attachments.'.$id);
				$rcmail->output->command('remove_from_attachment_list', "rcmfile$id");
			}     

		}
	}	

	function retrieve_compose_id(){
		$rcmail = rcmail::get_instance();
		$compose_data_keys = array_keys($_SESSION);
		$compose_data_keys = array_filter($compose_data_keys , array($this, 'isComposeDataKey'));
		$file_ids = array_keys(reset($_SESSION['plugins']['linshare']['rc_Attachments']));
		$file_id_to_find = $file_ids[0];

		foreach ($compose_data_keys as $compose_id){
			$msg_attachments = $_SESSION[$compose_id]['attachments'];     

			if($msg_attachments != null){
				foreach($msg_attachments as $key => $attachment){
					if($attachment['id'] == $file_id_to_find){
						return $_SESSION[$compose_id]['id'];
					}
				}
			}

		}  
	}

	function share_linshare($args){ 

		if($_SESSION['plugins']['linshare']['uuids']!=NULL){
			$credentials = $this->getUserCredentials();
			$mail_array = $_SESSION['plugins']['linshare']['emailAddresses'];         
			$url = $this->get_base();				
			$share_url = $url."/share/multiplesharedocuments";  

			foreach ($mail_array as $mail) { 

				$postfields = "";       

      //Share uploaded files with each recipient

				foreach ($_SESSION['plugins']['linshare']['uuids'] as $uuid){
					$postfields = $postfields."&file=".$uuid;        
				}

				$postfields = "targetMail=".$mail.$postfields; 

				$headers = array("Authorization: Basic " . base64_encode($credentials["username"] . ':' . $credentials["password"]));
				$options = array(
					CURLOPT_RETURNTRANSFER => true,
					CURLOPT_URL => $share_url,
					CURLOPT_POST => 1,
					CURLOPT_HEADER => 0,             
					CURLOPT_HTTPHEADER =>$headers,
					CURLOPT_POSTFIELDS => $postfields,
					CURLOPT_SSL_VERIFYPEER=> false
					);             

				if ($ch = curl_init()) {
					curl_setopt_array($ch, $options);          
					$response=curl_exec($ch);        

					if(!curl_errno($ch)){
						$info = curl_getinfo($ch);
					}

					curl_close($ch); 
				}       
			}    

		}

		$_SESSION['plugins']['linshare']['uuids']=array();
		$_SESSION['plugins']['linshare']['fileIds']=array();
	}  

	function get_base(){		   
		$rcmail = rcmail::get_instance();
		$prefs = $rcmail->user->get_prefs();

		if($prefs['urlLinshare'] != '')
			$url = $prefs['urlLinshare'];		
		else{
			$this->load_config();
			$url = $rcmail->config->get('linshare_url');
		}

		return $url;
	}

	function queueFile($args){ 
    //Saving file's name
		$_SESSION['plugins']['linshare']['filePaths'][$args['name']] = $args['path']; 
		$_SESSION['plugins']['linshare']['fileIds'][$args['name']] = $args['id']; 
		return $args;
	}

	function originalName($filePath){

		foreach($_SESSION['plugins']['linshare']['filePaths'] as $name =>$path){
			if($path==$filePath){        
				return $name;     
			}
		}
	} 

	function cleanup($args){
		rcmail::get_instance()->plugins->exec_hook('attachments_cleanup', array()); 
		return $args;
	}

	function linshare_sections_list($p)
	{
		$this->add_texts('localization/');    

		$p['list']['linshare'] = array(
			'id' => 'linshare', 'section' => $this->gettext('linshareSettings')
			);

		return $p;
	}

	function linshare_list($p){
		$rcmail = rcmail::get_instance();    
		$prefs = rcmail::get_instance()->user->get_prefs();
		$urlLinshareValue = $prefs['urlLinshare'];
		$loginLinshareValue = $prefs['loginLinshare'];
		$pwdLinshareValue = $prefs['pwdLinshare'];
		$textLinshareValue = $prefs['textLinshare']; 
		$this->add_texts('localization');
		$authKind = $this->getAuthKind();

		if ($p['section'] == 'linshare') {

			if($urlLinshareValue != ''){
				$urlLinshare=array(
					'title'=>$this->gettext('urlLinshareLabel'), 
					'content'=>"<input name='urlLinshareName' 
					type='url' 
					style='width:30em; height:1.5em' 
					value='$urlLinshareValue'>"
					);
			}
			if($urlLinshareValue == ''){
				$this->load_config();
				$urlDefault = $rcmail->config->get('linshare_url');
				$urlLinshare=array(
					'title'=>$this->gettext('urlLinshareLabel'), 
					'content'=>"<input name='urlLinshareName' 
					type='url' 
					style='width:30em; height:1.5em' 
					placeholder='$urlDefault'>"
					);
			}
			$loginLinshare=array(
				'title'=>$this->gettext('loginLinshareLabel'), 
				'content'=>"<input name='loginLinshareName' 
				type='email' 
				style='width:30em; height:1.5em' 
				value='$loginLinshareValue'>"
				);
			$pwdLinshare=array(
				'title'=>$this->gettext('pwdLinshareLabel'), 
				'content'=>"<input type='password' 
				name='pwdLinshareName' 
				value='$pwdLinshareValue' 
				style='width:30em; height:1.5em' >"
				);

			if($textLinshareValue == ''){        
				$this->load_config();
				$message = $rcmail->config->get('linshare_message');
				$textLinshare=array(
					'title'=>$this->gettext('textLinshareLabel'), 
					'content'=>"<textarea id='textLinshareID' placeholder='$message' name='textLinshareName' style='width:30em; height:8em'></textarea>");
			}

			if($textLinshareValue != ''){
				$textLinshare=array(
					'title'=>$this->gettext('textLinshareLabel'), 
					'content'=>"<textarea id='textLinshareID' name='textLinshareName' style='width:30em; height:8em'>$textLinshareValue</textarea>");
			}
			$options = array(
				'urlLinshare' => $urlLinshare
			);

			if ($authKind == linshare::SIMPLE_AUTH_KIND) {
				$options['loginLinshare'] = $loginLinshare;
				$options['pwdLinshare'] = $pwdLinshare;
			}

			$options['textLinshare'] = $textLinshare;
			$p['blocks']['main'] = array(
				'name' => $this->gettext('linshareAuthentication'),  
				'options' => $options
				);
		}

		return $p;      
	}

	function linshare_save($p){   
		$this->add_texts('localization');
		$authKind = $this->getAuthKind();

		if ($p['section'] == 'linshare') {
			$p['prefs']['urlLinshare'] = rcube_utils::get_input_value('urlLinshareName', rcube_utils::INPUT_POST);

			if ($authKind == linshare::SIMPLE_AUTH_KIND) {
				$p['prefs']['loginLinshare'] = rcube_utils::get_input_value('loginLinshareName', rcube_utils::INPUT_POST);
				$p['prefs']['pwdLinshare'] = rcube_utils::get_input_value('pwdLinshareName', rcube_utils::INPUT_POST);
			}

			$p['prefs']['textLinshare'] = rcube_utils::get_input_value('textLinshareName', rcube_utils::INPUT_POST);
		}

		return $p; 
	}

	function get_emailAddresses($p){
		$to = $this->splitMail($p['headers']['To']);
		$cc = $this->splitMail($p['headers']['Cc']);
		$bcc = $this->splitMail($p['headers']['Bcc']);

		$a = array_merge($to, $cc, $bcc);
		$_SESSION['plugins']['linshare']['emailAddresses'] = array_filter($a);
	}

	function splitMail($stringMail){
		$finalArrayMail = array();
		$initialArrayMail = explode(',', $stringMail);    

		$finalArrayMail = array_map( array($this,'extract_mail'), $initialArrayMail); 
		return $finalArrayMail;   
	}  

	function extract_mail($str){
		$regex = '#.*\<(.*)\>.*$#';
		$str = trim($str);      
		$str = preg_replace($regex, '$1' ,$str);
		return $str;
	}

	function isComposeDataKey($p){
		return strpos($p,'compose_data_') === 0;
	}
}
